DEFINT A-Z

DECLARE SUB SelectWeapon (Weapon$)
DECLARE SUB GetInput (Row%, Col%, Variable$)
DECLARE SUB ResaveGameFile ()
DECLARE FUNCTION WeaponName$ (Number%)
DECLARE FUNCTION FileExists% (FileName$)
DECLARE FUNCTION FindValue% (Expression$)

'$INCLUDE: 'QB45.BI'
'$INCLUDE: 'QB.BI'

CONST TRUE = -1, False = 0
CONST VersionNum$ = "1.0"

TYPE WeaponType
	WeaponName AS STRING * 15
	WeaponNumber AS INTEGER
	MaxNumber AS INTEGER
	Description AS STRING * 180
	Picture AS STRING * 112
END TYPE
TYPE SaveGameFormat
	Mission AS STRING * 1
	CurEnergy AS STRING * 3
	MaxEnergy AS STRING * 3
	Missiles AS STRING * 1
	SubWeap1 AS STRING * 1
	SubWeap2 AS STRING * 1
	SubWeap3 AS STRING * 1
	NumWeap1 AS STRING * 1
	NumWeap2 AS STRING * 1
	NumWeap3 AS STRING * 1
	BarGraph AS STRING * 2
	LastMission AS STRING * 16
	Marker AS STRING * 2
END TYPE
DIM SHARED InRegX AS RegTypeX, OutRegX AS RegTypeX
DIM SHARED Weapon(0 TO 6) AS WeaponType
DIM SHARED SaveGame(2 TO 9) AS SaveGameFormat
DIM TempGame AS SaveGameFormat

'****************************************************************************'
'***    Loading of data files                                             ***'
'****************************************************************************'
IF FileExists("THEX2ED.DAT") THEN
	OPEN "THEX2ED.DAT" FOR BINARY AS #1
	FOR Lp = 1 TO 6
		GET #1, , Weapon(Lp)
	NEXT Lp
	CLOSE #1
	Weapon(0).WeaponName = "nothing"
	Weapon(0).WeaponNumber = 0
	Weapon(0).MaxNumber = 0
	Weapon(0).Description = ""
	Weapon(0).Picture = STRING$(112, 255)
ELSE
	PRINT "    PROBLEM:  Cannot find the data file THEX2ED.DAT"
	PRINT "INFORMATION:  THEX2ED.DAT is a data file used by this program and should"
	PRINT "              have accompanied this program when you obtained it."
	PRINT " SUGGESTION:  You must run THEX2ED.EXE in your Firehawk directory and must"
	PRINT "              have the THEX2ED.DAT file in then same directory."
	END
END IF

IF FileExists("SAVEGM.DAT") THEN
	OPEN "SAVEGM.DAT" FOR BINARY AS #1
	FOR Lp = 2 TO 9
		GET #1, , SaveGame(Lp)
	NEXT Lp
	CLOSE #1
ELSE
	PRINT "    PROBLEM:  Cannot find the save game file SAVEGM.DAT"
	PRINT "INFORMATION:  SAVEGM.DAT is the save game file created by Firehawk when you"
	PRINT "              advance levels."
	PRINT " SUGGESTION:  Put THEX2ED.EXE and THEX2ED.DAT into your Firehawk directory"
	PRINT "              and try running this program again."
	END
END IF

'****************************************************************************'
'***    Start of program                                                  ***'
'****************************************************************************'
SCREEN 0: WIDTH 80, 25: COLOR 15, 1: CLS
CALL DoWindow(3, 5, 5, 73 + LEN(VersionNum$), 2, 10, 2, 0, 1, "! Message !")
CALL FastPrt("The FIREHAWK Saved Game Editor, version " + VersionNum$ + ", by JL Enterprises, 1992", 4, 7, 47)


'****************************************************************************'
'***    Main menu                                                         ***'
'****************************************************************************'
Cursor = 12
MainMenu:
CALL DoWindow(10, 10, 22, 50, 4, 11, 3, 1, 0, ": Selection :")
CALL FastPrt("Please select the mission to edit:", 10, 12, 62)
FOR Lp = 2 TO 9
	IF ASC(SaveGame(Lp).Mission) <> 0 THEN
		CALL FastPrt("Mission" + STR$(ASC(SaveGame(Lp).Mission)), 10 + Lp, 20, 63)
	ELSE
		CALL FastPrt("Mission" + STR$(Lp), 10 + Lp, 20, 56)
	END IF
NEXT Lp
CALL FastPrt("<ENTER> to edit mission, <DELETE> to", 21, 12, 62)
CALL FastPrt("delete it, or " + CHR$(24) + " and " + CHR$(25) + " to move cursor", 22, 12, 62)
CALL FastPrt(CHR$(16), Cursor, 18, 60)
DO
	SELECT CASE INKEY$
		CASE CHR$(0) + CHR$(72) 'Up-Arrow
			CALL FastPrt(" ", Cursor, 18, 60)
			Cursor = Cursor - 1
			IF Cursor = 11 THEN Cursor = 19
			CALL FastPrt(CHR$(16), Cursor, 18, 60)
		CASE CHR$(0) + CHR$(80) 'Dn-Arrow
			CALL FastPrt(" ", Cursor, 18, 60)
			Cursor = Cursor + 1
			IF Cursor = 20 THEN Cursor = 12
			CALL FastPrt(CHR$(16), Cursor, 18, 60)
		CASE CHR$(0) + CHR$(83) 'Delete
			CALL DoWindow(15, 55, 19, 78, 4, 12, 4, 1, 0, "? Question ?")
			CALL FastPrt("Are you sure you want", 16, 56, 79)
			CALL FastPrt("to delete mission" + STR$(Cursor - 10) + "?", 17, 56, 79)
			CALL FastPrt("(Yes/No)", 18, 62, 79)
			DO
				SELECT CASE UCASE$(INKEY$)
					CASE "Y"
						SaveGame(Cursor - 10).Mission = STRING$(1, 0)
						SaveGame(Cursor - 10).CurEnergy = STRING$(3, 0)
						SaveGame(Cursor - 10).MaxEnergy = STRING$(3, 0)
						SaveGame(Cursor - 10).Missiles = STRING$(1, 0)
						SaveGame(Cursor - 10).SubWeap1 = STRING$(1, 0)
						SaveGame(Cursor - 10).SubWeap2 = STRING$(1, 0)
						SaveGame(Cursor - 10).SubWeap3 = STRING$(1, 0)
						SaveGame(Cursor - 10).NumWeap1 = STRING$(1, 0)
						SaveGame(Cursor - 10).NumWeap2 = STRING$(1, 0)
						SaveGame(Cursor - 10).NumWeap3 = STRING$(1, 0)
						SaveGame(Cursor - 10).BarGraph = STRING$(2, 0)
						SaveGame(Cursor - 10).LastMission = STRING$(16, 0)
						SaveGame(Cursor - 10).Marker = STRING$(2, 0)
						CALL ResaveGameFile
						CALL FastPrt("Mission" + STR$(Cursor - 10), Cursor, 20, 56)
						EXIT DO
					CASE "N"
						EXIT DO
					CASE IS <> ""
						SOUND 550, .5
					CASE ELSE
				END SELECT
			LOOP
			FOR Lp = 14 TO 20: CALL FastPrt(SPACE$(26), Lp, 54, 31): NEXT Lp
		CASE CHR$(13)           'Enter
			EXIT DO
		CASE CHR$(27)           'Escape
			CALL DoWindow(15, 55, 19, 78, 4, 12, 4, 1, 0, "? Question ?")
			CALL FastPrt("Are you sure you want", 16, 56, 79)
			CALL FastPrt("to quit to DOS?", 17, 56, 79)
			CALL FastPrt("(Yes/No)", 18, 62, 79)
			DO
				SELECT CASE UCASE$(INKEY$)
					CASE "Y"
						FOR Lp = 14 TO 20: CALL FastPrt(SPACE$(26), Lp, 54, 31): NEXT Lp
						COLOR 15, 0: CLS : END
					CASE "N"
						EXIT DO
					CASE IS <> ""
						SOUND 550, .5
					CASE ELSE
				END SELECT
			LOOP
			FOR Lp = 14 TO 20: CALL FastPrt(SPACE$(26), Lp, 54, 31): NEXT Lp
		CASE IS <> ""
			SOUND 550, .5
		CASE ELSE
	END SELECT
LOOP
FOR Lp = 9 TO 23: CALL FastPrt(SPACE$(43), Lp, 9, 31): NEXT Lp


'****************************************************************************'
'***    Mission Editor Screen                                             ***'
'****************************************************************************'
CurrentMission = Cursor - 10: Modified = False: Cursor = 12
TempGame = SaveGame(CurrentMission)
IF ASC(TempGame.Mission) = 0 THEN TempGame.Mission = CHR$(CurrentMission)
EditMenu:
CALL DoWindow(10, 10, 23, 49, 4, 11, 3, 1, 0, ": Selection :][editing mission" + STR$(ASC(TempGame.Mission)))
CALL FastPrt("Please select the attribute to edit:", 10, 12, 62)
CALL FastPrt("Current Energy       [   ]", 12, 18, 63)
CALL FastPrt("Maximum Energy       [   ]", 13, 18, 63)
CALL FastPrt("Number of Missiles   [  ]", 14, 18, 63)
CALL FastPrt("Sub-Weapon #1        [        ]", 15, 18, 63)
CALL FastPrt("Sub-Weapon #2        [        ]", 16, 18, 63)
CALL FastPrt("Sub-Weapon #3        [        ]", 17, 18, 63)
CALL FastPrt("Number of SW #1      [  ]", 18, 18, 63)
CALL FastPrt("Number of SW #2      [  ]", 19, 18, 63)
CALL FastPrt("Number of SW #3      [  ]", 20, 18, 63)
CALL FastPrt(RIGHT$("  " + STR$(FindValue(TempGame.CurEnergy)), 3), 12, 40, 63)
CALL FastPrt(RIGHT$("  " + STR$(FindValue(TempGame.MaxEnergy)), 3), 13, 40, 63)
CALL FastPrt(RIGHT$(" " + STR$(FindValue(TempGame.Missiles)), 2), 14, 40, 63)
CALL FastPrt(LEFT$(WeaponName$(FindValue(TempGame.SubWeap1)), 8), 15, 40, 63)
CALL FastPrt(LEFT$(WeaponName$(FindValue(TempGame.SubWeap2)), 8), 16, 40, 63)
CALL FastPrt(LEFT$(WeaponName$(FindValue(TempGame.SubWeap3)), 8), 17, 40, 63)
CALL FastPrt(RIGHT$(" " + STR$(FindValue(TempGame.NumWeap1)), 2), 18, 40, 63)
CALL FastPrt(RIGHT$(" " + STR$(FindValue(TempGame.NumWeap2)), 2), 19, 40, 63)
CALL FastPrt(RIGHT$(" " + STR$(FindValue(TempGame.NumWeap3)), 2), 20, 40, 63)
CALL FastPrt("<ENTER> to edit attribute, " + CHR$(24) + " and " + CHR$(25), 22, 12, 62)
CALL FastPrt("to move cursor, or <ESC> when done", 23, 12, 62)
CALL FastPrt(CHR$(16), Cursor, 16, 60)
EditLoop:
DO
	SELECT CASE INKEY$
		CASE CHR$(9)
			IF CurrentMission <> 2 THEN
				SOUND 550, .5
			ELSE
				IF ASC(TempGame.Mission) = 2 THEN
					TempGame.Mission = CHR$(1)
					CALL FastPrt("1", 9, 43, 59)
				ELSE
					TempGame.Mission = CHR$(2)
					CALL FastPrt("2", 9, 43, 59)
				END IF
				Modified = TRUE
			END IF
		CASE CHR$(0) + CHR$(72) 'Up-Arrow
			CALL FastPrt(" ", Cursor, 16, 60)
			Cursor = Cursor - 1
			IF Cursor = 11 THEN Cursor = 20
			CALL FastPrt(CHR$(16), Cursor, 16, 60)
		CASE CHR$(0) + CHR$(80) 'Dn-Arrow
			CALL FastPrt(" ", Cursor, 16, 60)
			Cursor = Cursor + 1
			IF Cursor = 21 THEN Cursor = 12
			CALL FastPrt(CHR$(16), Cursor, 16, 60)
		CASE CHR$(13)           'Enter
			SELECT CASE Cursor
				CASE 12 'Current Energy
					CALL GetInput(12, 40, TempGame.CurEnergy)
					TempGame.BarGraph = MKI$(FindValue(TempGame.CurEnergy) \ 5)
					IF TempGame.CurEnergy <> SaveGame(CurrentMission).CurEnergy THEN Modified = TRUE
				CASE 13 'Maximum Energy
					CALL GetInput(13, 40, TempGame.MaxEnergy)
					IF TempGame.MaxEnergy <> SaveGame(CurrentMission).MaxEnergy THEN Modified = TRUE
				CASE 14 'Number of Missiles
					CALL GetInput(14, 40, TempGame.Missiles)
					IF TempGame.Missiles <> SaveGame(CurrentMission).Missiles THEN Modified = TRUE
				CASE 15 'Sub-Weapon #1
					FOR Lp = 9 TO 24: CALL FastPrt(SPACE$(42), Lp, 9, 31): NEXT Lp
					CALL SelectWeapon(TempGame.SubWeap1)
					IF TempGame.SubWeap1 <> SaveGame(CurrentMission).SubWeap1 THEN Modified = TRUE
					GOTO EditMenu
				CASE 16 'Sub-Weapon #2
					FOR Lp = 9 TO 24: CALL FastPrt(SPACE$(42), Lp, 9, 31): NEXT Lp
					CALL SelectWeapon(TempGame.SubWeap2)
					IF TempGame.SubWeap2 <> SaveGame(CurrentMission).SubWeap2 THEN Modified = TRUE
					GOTO EditMenu
				CASE 17 'Sub-Weapon #3
					FOR Lp = 9 TO 24: CALL FastPrt(SPACE$(42), Lp, 9, 31): NEXT Lp
					CALL SelectWeapon(TempGame.SubWeap3)
					IF TempGame.SubWeap3 <> SaveGame(CurrentMission).SubWeap3 THEN Modified = TRUE
					GOTO EditMenu
				CASE 18 'Number of SW #1
					CALL GetInput(18, 40, TempGame.NumWeap1)
					IF TempGame.NumWeap1 <> SaveGame(CurrentMission).NumWeap1 THEN Modified = TRUE
				CASE 19 'Number of SW #2
					CALL GetInput(19, 40, TempGame.NumWeap2)
					IF TempGame.NumWeap2 <> SaveGame(CurrentMission).NumWeap2 THEN Modified = TRUE
				CASE 20 'Number of SW #3
					CALL GetInput(20, 40, TempGame.NumWeap3)
					IF TempGame.NumWeap3 <> SaveGame(CurrentMission).NumWeap3 THEN Modified = TRUE
				CASE ELSE
			END SELECT
		CASE CHR$(27)           'Escape
			CALL DoWindow(15, 55, 19, 78, 4, 12, 4, 1, 0, "? Question ?")
			CALL FastPrt("Are you done editing", 16, 56, 79)
			CALL FastPrt("this mission?", 17, 56, 79)
			CALL FastPrt("(Yes/No)", 18, 62, 79)
			DO
				SELECT CASE UCASE$(INKEY$)
					CASE "Y"
						EXIT DO
					CASE "N"
						FOR Lp = 14 TO 20: CALL FastPrt(SPACE$(26), Lp, 54, 31): NEXT Lp
						GOTO EditLoop
					CASE IS <> ""
						SOUND 550, .5
					CASE ELSE
				END SELECT
			LOOP
			FOR Lp = 14 TO 20: CALL FastPrt(SPACE$(26), Lp, 54, 31): NEXT Lp
			IF Modified THEN
				CALL DoWindow(15, 55, 19, 78, 4, 12, 4, 1, 0, "? Question ?")
				CALL FastPrt("Do you want to save", 16, 56, 79)
				CALL FastPrt("these changes?", 17, 56, 79)
				CALL FastPrt("(Yes/No)", 18, 62, 79)
				DO
					SELECT CASE UCASE$(INKEY$)
						CASE "Y"
							SaveGame(CurrentMission) = TempGame
							CALL ResaveGameFile
							EXIT DO
						CASE "N"
							EXIT DO
						CASE IS <> ""
							SOUND 550, .5
						CASE ELSE
					END SELECT
				LOOP
				FOR Lp = 14 TO 20: CALL FastPrt(SPACE$(26), Lp, 54, 31): NEXT Lp
			END IF
			FOR Lp = 9 TO 24: CALL FastPrt(SPACE$(42), Lp, 9, 31): NEXT Lp
			Cursor = CurrentMission + 10: GOTO MainMenu
		CASE IS <> ""
			SOUND 550, .5
		CASE ELSE
	END SELECT
LOOP


'****************************************************************************'
'***    Error handler                                                     ***'
'****************************************************************************'
END
ErrorTrap:
	RESUME NEXT

FUNCTION FileExists (FileName$)
	Temp$ = FileName$ + CHR$(0)
	InRegX.AX = &H4E00
	InRegX.CX = 0
	InRegX.DS = VARSEG(Temp$)
	InRegX.DX = SADD(Temp$)
	CALL INTERRUPTX(&H21, InRegX, OutRegX)
	FileExists = ((OutRegX.FLAGS AND 1) = 0)
END FUNCTION

FUNCTION FindValue (Expression$)
	SELECT CASE LEN(Expression$)
		CASE 1 'full byte used
			Temp = (ASC(Expression$) \ 16) * 10
			Temp = Temp + (ASC(Expression$) AND 15)
		CASE 3 'only lower-half used
			Temp = (ASC(Expression$) AND 15) * 100
			Temp = Temp + (ASC(MID$(Expression$, 2, 1)) AND 15) * 10
			Temp = Temp + (ASC(MID$(Expression$, 3, 1)) AND 15)
		CASE ELSE
	END SELECT
	FindValue = Temp
END FUNCTION

SUB GetInput (Row, Col, Variable$)
	HiLited = TRUE
	Cursor = Col
	SELECT CASE LEN(Variable$)
		CASE 1
			NewValue$ = RIGHT$(" " + STR$(FindValue(Variable$)), 2)
			DO
				SELECT CASE HiLited
					CASE TRUE
						CALL FastPrt(RIGHT$(" " + STR$(FindValue(Variable$)), 2), Row, Col, 112)
					CASE False
						CALL FastPrt(NewValue$, Row, Col, 63)
					CASE ELSE
				END SELECT
				LOCATE Row, Cursor, 1
				A$ = INKEY$
				SELECT CASE A$
					CASE CHR$(0) + CHR$(77) 'Right-Arrow
						IF Cursor = Col + LEN(NewValue$) THEN
							SOUND 550, .5
						ELSE
							Cursor = Cursor + 1
							HiLited = False
						END IF
					CASE CHR$(0) + CHR$(75) 'Left-Arrow
						IF Cursor = Col THEN
							SOUND 550, .5
						ELSE
							HiLited = False
							Cursor = Cursor - 1
						END IF
					CASE CHR$(8)            'Back-space
						IF Cursor = Col THEN
							SOUND 550, .5
						ELSE
							HiLited = False
							Cursor = Cursor - 1
							MID$(NewValue$, Cursor - Col + 1) = LEFT$(MID$(NewValue$ + " ", Cursor - Col + 2) + "  ", LEN(NewValue$))
						END IF
					CASE CHR$(13)           'Enter
						Variable$ = CHR$((VAL(NewValue$) \ 10) * 16 + VAL(NewValue$) MOD 10)
						CALL FastPrt(RIGHT$(" " + STR$(FindValue(Variable$)), 2), Row, Col, 63)
						LOCATE , , 0
						EXIT SUB
					CASE CHR$(27)           'Escape
						CALL FastPrt(RIGHT$(" " + STR$(FindValue(Variable$)), 2), Row, Col, 63)
						LOCATE , , 0
						EXIT SUB
					CASE "0" TO "9"         '0,1,2,3,4,5,6,7,8,9
						IF Cursor = Col + LEN(NewValue$) THEN
							SOUND 550, .5
						ELSE
							IF HiLited = TRUE THEN
								HiLited = False
								NewValue$ = A$ + SPACE$(LEN(NewValue$) - 1)
								Cursor = Cursor + 1
							ELSE
								MID$(NewValue$, Cursor - Col + 1) = A$
								Cursor = Cursor + 1
							END IF
						END IF
					CASE IS <> ""
						SOUND 550, .5
					CASE ELSE
				END SELECT
			LOOP
		CASE 3
			NewValue$ = RIGHT$("  " + STR$(FindValue(Variable$)), 3)
			DO
				SELECT CASE HiLited
					CASE TRUE
						CALL FastPrt(RIGHT$("  " + STR$(FindValue(Variable$)), 3), Row, Col, 112)
					CASE False
						CALL FastPrt(NewValue$, Row, Col, 63)
					CASE ELSE
				END SELECT
				LOCATE Row, Cursor, 1
				A$ = INKEY$
				SELECT CASE A$
					CASE CHR$(0) + CHR$(77) 'Right-Arrow
						IF Cursor = Col + LEN(NewValue$) THEN
							SOUND 550, .5
						ELSE
							Cursor = Cursor + 1
							HiLited = False
						END IF
					CASE CHR$(0) + CHR$(75) 'Left-Arrow
						IF Cursor <= Col THEN
							SOUND 550, .5
						ELSE
							HiLited = False
							Cursor = Cursor - 1
						END IF
					CASE CHR$(8)            'Back-space
						IF Cursor = Col THEN
							SOUND 550, .5
						ELSE
							HiLited = False
							Cursor = Cursor - 1
							MID$(NewValue$, Cursor - Col + 1) = LEFT$(MID$(NewValue$ + " ", Cursor - Col + 2) + "  ", LEN(NewValue$))
						END IF
					CASE CHR$(13)           'Enter
						Variable$ = CHR$(VAL(NewValue$) \ 100) + CHR$((VAL(NewValue$) MOD 100) \ 10) + CHR$(VAL(NewValue$) MOD 10)
						CALL FastPrt(RIGHT$("  " + STR$(FindValue(Variable$)), 3), Row, Col, 63)
						LOCATE , , 0
						EXIT SUB
					CASE CHR$(27)           'Escape
						CALL FastPrt(RIGHT$("  " + STR$(FindValue(Variable$)), 3), Row, Col, 63)
						LOCATE , , 0
						EXIT SUB
					CASE "0" TO "9"         '0,1,2,3,4,5,6,7,8,9
						IF Cursor = Col + LEN(NewValue$) THEN
							SOUND 550, .5
						ELSE
							IF HiLited = TRUE THEN
								HiLited = False
								NewValue$ = A$ + SPACE$(LEN(NewValue$) - 1)
								Cursor = Cursor + 1
							ELSE
								MID$(NewValue$, Cursor - Col + 1) = A$
								Cursor = Cursor + 1
							END IF
						END IF
					CASE IS <> ""
						SOUND 550, .5
					CASE ELSE
				END SELECT
			LOOP
		CASE ELSE
	END SELECT
END SUB

SUB ResaveGameFile
	FOR Lp = 3 TO 9
		Temp$ = SaveGame(Lp - 1).Mission + SaveGame(Lp - 1).CurEnergy + SaveGame(Lp - 1).MaxEnergy + SaveGame(Lp - 1).Missiles
		Temp$ = Temp$ + SaveGame(Lp - 1).SubWeap1 + SaveGame(Lp - 1).SubWeap2 + SaveGame(Lp - 1).SubWeap3 + SaveGame(Lp - 1).NumWeap1
		SaveGame(Lp).LastMission = Temp$ + SaveGame(Lp - 1).NumWeap3 + SaveGame(Lp - 1).BarGraph
	NEXT Lp
	OPEN "SAVEGM.DAT" FOR BINARY AS #1
	FOR Lp = 2 TO 9
		PUT #1, , SaveGame(Lp)
	NEXT Lp
	CLOSE #1
END SUB

SUB SelectWeapon (WeaponID$)
	CALL DoWindow(10, 3, 23, 78, 4, 11, 3, 1, 0, ": Selection :")
	CALL FastPrt("Please select a sub-weapon:", 10, 5, 62)
	FOR Lp = 0 TO 6
		CALL FastPrt(Weapon(Lp).WeaponName, 11 + Lp, 15, 63)
		IF Weapon(Lp).WeaponNumber = FindValue(WeaponID$) THEN Number = Lp
	NEXT Lp
	DO
		CALL FastPrt(CHR$(16), 11 + Number, 13, 60)
		FOR Lp = 18 TO 23
			CALL FastPrt(SPACE$(40), Lp, 4, 63)
		NEXT Lp
		Col = 46: Row = 10
		FOR Lp = 1 TO 112
			CALL FastPrt("", Row, Col, ASC(MID$(Weapon(Number).Picture, Lp, 1)) \ 16 + 48)
			Col = Col + 2
			CALL FastPrt("", Row, Col, ASC(MID$(Weapon(Number).Picture, Lp, 1)) MOD 16 + 48)
			Col = Col + 2
			IF Col = 78 THEN Col = 46: Row = Row + 1
		NEXT Lp
		COLOR 14, 3
		CALL WordWrap(RTRIM$(Weapon(Number).Description) + "  Maximum number allowed is" + STR$(Weapon(Number).MaxNumber), 18, 4, 40)
		DO
			A$ = INKEY$
			SELECT CASE A$
				CASE CHR$(0) + CHR$(72) 'Up-Arrow
					CALL FastPrt(" ", 11 + Number, 13, 63)
					Number = Number - 1
					IF Number < 0 THEN Number = 6
					EXIT DO
				CASE CHR$(0) + CHR$(80) 'Dn-Arrow
					CALL FastPrt(" ", 11 + Number, 13, 63)
					Number = (Number + 1) MOD 7
					EXIT DO
				CASE CHR$(13)       'Enter
					WeaponID$ = CHR$(Weapon(Number).WeaponNumber)
					FOR Lp = 9 TO 24
						CALL FastPrt(SPACE$(78), Lp, 2, 31)
					NEXT Lp
					EXIT SUB
				CASE CHR$(27)       'Escape
					FOR Lp = 9 TO 24
						CALL FastPrt(SPACE$(78), Lp, 2, 31)
					NEXT Lp
					EXIT SUB
				CASE IS <> ""
					SOUND 550, .5
				CASE ELSE
			END SELECT
		LOOP
	LOOP
END SUB

FUNCTION WeaponName$ (Number)
	FOR Lp = 0 TO 6
		IF Weapon(Lp).WeaponNumber = Number THEN
			WeaponName$ = Weapon(Lp).WeaponName
			EXIT FUNCTION
		END IF
	NEXT Lp
	WeaponName$ = "unknown"
END FUNCTION

